********************************************************************************
********************************************************************************
***         Create final database 
********************************************************************************
********************************************************************************

clear all
set more off

*To be personalized
*gl testing_AR /Users/pv/Dropbox/Testing_AR/
*gl testing_AR "/Users/pierrecahuc/Dropbox/Testing/Testing_AReduite/"
gl testing_AR "/Users/helene/Dropbox/#Work/#Projets/Testing AR/Testing_AR/"

gl testing_AR_in "${testing_AR}Prog/Prog for JHR/Data/Raw data/"	
gl testing_AR_intermediate "${testing_AR}Prog/Prog for JHR/Data/Intermediate tables/"
gl testing_AR_out "${testing_AR}Prog/Prog for JHR/Data/Final table/"


********************************************************************************
* STEP 1: Create Panel database with monthly administrative unemployment data
********************************************************************************

* Start with the monthly panel
use "${testing_AR_intermediate}hmai20_de_mensuel.dta", clear

* Label
label var individu "Identifiant individu du FNA"
label var ar "=1 si AR dans le mois"
label var indemnisation "Montant de l'indemnisation en fin de mois"
label var aides_versees "Montant des aides en fin de mois"
label var nbj_consommes_payes "Nombre de jours consommes dans le mois"
label var nbj_consommes_dans_le_droit "Nombre de jours consommes dans le droit"
label var kpharp "Heures d'AR"
label var kqbarp "Revenu d'AR"
label var etat_fin_de_mois "Situation du DE en fin de mois"
label var krod "Identifiant du droit"
label var allocation_type "Type d'allocation (ARE, ASS...)"
label var kcemp "Situation particulière au regard de l'emploi"
label var mtt_arce "Montant de l'ARCE versee au DE"

* get permanent identifier (kcrna) 
merge m:1 individu using "${testing_AR_in}hmai20_ind.dta", keepusing(kcrna)
format %12.0g individu
keep if _merge == 3 																
drop _merge

* last extraction in May 2020, we keep data until feb 2020
drop if annee >= 2021 | (annee == 2020 & mois >= 3)

* create panel id variable
egen indiv=group(kcrna)
gen date=mofd(mdy(mois,1,annee))
format date %tm

sort indiv date individu
order indiv kcrna individu date annee mois
																				
* -> individuals get UB before 2016 m7 : 291
by indiv : egen indemn_avant_juil_2017 = max((indemnisation > 0 & indemnisation != . & (annee < 2016 | (annee == 2016 & mois < 7))))

* -> individuals appear on the list before 7/2016 : 66,991 
by indiv : egen DE_avant_juil_2017 = max(annee < 2016 | (annee == 2016 & mois < 7))

* People (are supposed to) enter unemployment between 7/2016 and 11/2016 
drop if date < mofd(mdy(7,1,2016))

* Pb : few individuals have multiple "individu" id in the same month = duplicates --> remove it by keeping the most recent 
bys indiv date : gen row_dupli = _N>1 // # 308

* we keep the most recent "individu" id 
bys indiv individu : egen max_date_individu = max(date)
bys indiv : egen max_date_indiv = max(date)
drop if max_date_individu < max_date_indiv & row_dupli == 1

drop row_dupli
bys indiv date : gen row_dupli = _N>1 // still 111 individuals with duplicates 

* we drop the rest by keeping only the first "individu" that occurs
bys indiv date (individu) : gen dupli_id = _n
drop if dupli_id > 1
drop max_date_individu max_date_indiv row_dupli 

* declare data as panel 
xtset indiv date, monthly

* add missing date/rows
tsfill, full

* fill missing panel id  
replace annee=year(dofm(date)) if annee==.
replace mois=month(dofm(date)) if mois==.
* fill missing individual ids
replace kcrna = kcrna[_n-1] if kcrna == "" & indiv == indiv[_n-1]
replace individu = individu[_n-1] if individu == . & indiv == indiv[_n-1]
gsort indiv -date
replace kcrna = kcrna[_n-1] if kcrna == "" & indiv == indiv[_n-1]
replace individu = individu[_n-1] if individu == . & indiv == indiv[_n-1]

sort indiv date
order indiv kcrna individu date annee mois

* merge with experimental data population to keep only ind in the experiment 
merge m:1 kcrna using "${testing_AR_in}pop_pour_tirage_finale_no_dup.dta"

drop kcaaj kncts kqesfp kcdfa parent kcluse kcpaf1 kcasse kcmca kncte kcep2 ///
	 naf_* ident dc_adresseemail second_edu treated_net objet_net treated_brut ///
	 objet_brut kdpma groupe_ale
	 
keep if _merge == 3 
drop _merge

sort indiv date

*codebook kcrna // 148 514 --> - 183 ind compared to initial experimental population
*compress
*save "${testing_AR_data_exploit}exploitation_panel_tmp", replace

**********************
* STEP 2: We create the variables we need
**********************

*use "${testing_AR_data_exploit}exploitation_panel_tmp", clear

* we complete the missing obs
replace indemnisation=0 if indemnisation==.
replace aides_versees=0 if aides_versees==.
replace nbj_consommes_payes=0 if nbj_consommes_payes==.
replace nbj_consommes_dans_le_droit=0 if nbj_consommes_dans_le_droit==.
replace kpharp=0 if kpharp==.
replace kqbarp=0 if kqbarp==.

* recode ar variable
gen ar_=1 if ar=="O"
replace ar_=0 if ar=="N"
replace ar_=0 if ar_==.
drop ar
rename ar_ ar
label var ar "=1 si AR dans le mois"

* Calculate nbjoursmois
cap drop nbjoursmois
gen nbjoursmois=.
replace nbjoursmois=31 if mois==1 | mois==3 | mois==5 | mois==7 | mois==8 | mois==10 | mois==12
replace nbjoursmois=30 if mois==4 | mois==6 | mois==9 | mois==11 
replace nbjoursmois=28 if mois==2 
label var nbjoursmois "Nombre de jours dans le mois"

* first paid day by Pole emploi = kdpod
preserve
use "${testing_AR_in}hmai20_odd", clear
keep individu kdpod
drop if kdpod < mdy(7,1,2016) // The spell of the jobseekers in the experiment starts from July 1st, 2016. so we only kdpod after  July 1st, 2016
sort individu kdpod
by individu: keep if _n==1 // we only keep the first kdpod
save "${testing_AR_intermediate}kdpod.dta", replace
restore

preserve
use "${testing_AR_intermediate}hmai20_droits", clear
keep individu krod kpjdxp
rename kpjdxp kpjdxp_droit
save "${testing_AR_intermediate}kpjdxp.dta", replace
restore

merge m:1 individu using "${testing_AR_intermediate}kdpod"
drop if _merge==2
drop _merge

merge m:m individu krod using "${testing_AR_intermediate}kpjdxp"
drop if _merge==2
drop _merge

* drop some duplicates in terms of indiv*date because m:m merge 
duplicates drop indiv date, force 

erase "${testing_AR_intermediate}kdpod.dta"
erase "${testing_AR_intermediate}kpjdxp.dta"

* Correct for the periods before kdpod
replace ar=. if date < mofd(kdpod) 
replace kpharp=. if date < mofd(kdpod)
replace kqbarp=. if date < mofd(kdpod)
replace indemnisation=. if date < mofd(kdpod)

sort indiv date

* Reliquat = remaining benefits
replace allocation_type="ARE" if allocation_type=="DM"
gen reliquat = kpjdxp_droit - nbj_consommes_dans_le_droit if allocation_type=="ARE" | ///
															 allocation_type=="AREF" | ///
															 allocation_type=="AREF-PE"

bys indiv (date): replace reliquat=reliquat[_n-1] if reliquat==. & reliquat[_n-1]!=. & reliquat[_n-1] > nbjoursmois & ///
													 (allocation_type!="ARE" & allocation_type!="AREF" & allocation_type!="AREF-PE")
replace reliquat=0 if reliquat==.
replace reliquat=. if date < mofd(kdpod)

label var reliquat "Reliquat à la fin du mois"
label var kpjdxp_droit "Durée potentielle d'indemnisation pour le droit correspondant"
label var kpjdxp "Durée potentielle d'indemnisation à l'ODD"
label var kdpod "Date du 1e jour indemnisé (du 1er droit)"

* dummy for reliquat<0
cap drop reliquatnegatif
cap drop temp
sort indiv
by indiv: gen temp=reliquat<0
by indiv: egen reliquatnegatif=max(temp)
drop temp
label var reliquatnegatif "=1 si l'individu a / aura un reliquat négatif"

* we create month numbers
capture drop numero_mois
bys indiv (date): gen numero_mois=_n-7

* sortie totale = no benefits
cap drop sortietotale
gen sortietotale = indemnisation == 0 
replace sortietotale=. if indemnisation==.
label var sortietotale "Sortie totale (i.e. pas d'indemnisation dans le mois)"

* sortie definitive = no benefits until the end of the experiment
sort indiv numero_mois
cap drop sortiedef
gen sortiedef = 0
replace sortiedef = sortietotale==1 if numero_mois==37
foreach x in 36 35 34 33 32 31 30 29 28 27 26 25 24 23 22 21 20 19 18 17 16 15 14 13 12 11 10 9 8 7 6 5 4 3 2 1 0 -1 -2 -3 -4 -5 -6 {
replace sortiedef=1 if numero_mois==`x' & sortiedef[_n+1]==1 & indiv==indiv[_n+1] & sortietotale == 1
}
label var sortiedef "Sortie totale et définitive de l'indemnisation"

* Definition of var createur d'entreprise 
gen createur_entrep_tmp = 0 
replace createur_entrep_tmp = 1 if kcemp == "CEN"
bys indiv (numero_mois) : gen createur_entrep = sum(createur_entrep)
replace createur_entrep = 1 if createur_entrep > 1
drop createur_entrep_tmp
label var createur_entrep "Statut de créateur d'entreprise présent ou passé"


* indic debut and fin de spell (begining and end of spell)
capture drop debut_spell fin_spell 
gen debut_spell = (episode_rac_numero_mois == 1)
replace debut_spell = 0 if episode_rac_numero_mois == . 
bys indiv episode_rac_numero : egen fin_spell = max(episode_rac_numero_mois)
replace fin_spell = 1 if episode_rac_numero_mois == fin_spell
replace fin_spell = . if episode_rac_numero_mois == .
replace fin_spell = 0 if fin_spell != 1 

sort indiv date

* modification in the variables de revenus / heures d'ar (wage and hours of work while on claim)
capture drop revenu_ar
gen revenu_ar = kqbarp
replace revenu_ar = revenu_reconstitue if revenu_reconstitue != . 
replace revenu_ar = 0 if revenu_ar == . 
replace revenu_ar=. if date < mofd(kdpod) 

capture drop heures_ar
gen heures_ar = kpharp 
replace heures_ar = heures_reconstituees if heures_reconstituees != . 
replace heures_ar = 0 if heures_ar == . 
replace heures_ar=. if date < mofd(kdpod) 
	
compress
save "${testing_AR_out}exploitation_panel_tmp", replace

use "${testing_AR_out}exploitation_panel_tmp", clear

* Definition of the variable activité réduite indemnisée : iar 
capture drop iar iar
gen iar = etat_fin_de_mois == "IAR" & /// 
		  (indemnisation >= 1 & indemnisation !=.) & /// 
		  (heures_ar >= 1 & heures_ar !=.) & (revenu_ar >= 1 & revenu_ar != .) & /// 
		  (nbj_rac > nbj_consommes_payes) & nbj_rac !=. & nbj_consommes_payes !=. & !(fdd == "O" & reliquat == 0)
bysort indiv (numero_mois) : replace iar=0 if iar == 1 & iar[_n-1] == 0 & sortietotale[_n+1] == 1
bysort indiv (numero_mois) : replace iar=0 if iar == 1 & iar[_n+1] == 0 & debut_spell == 1  
replace iar=. if date < mofd(kdpod)


capture drop revenu_iar heures_iar
gen revenu_iar = (iar*revenu_ar)
gen heures_iar = (iar*heures_ar)

* Definition of the variable activité réduite non indemnisée : niar 
capture drop niar
gen niar = etat_fin_de_mois == "NIAR" & /// 
		   (indemnisation==0 & indemnisation !=.) & ///
		   (heures_ar >= 1 & heures_ar !=.) & (revenu_ar >= 1 & revenu_ar != .) & ///
		   (nbj_rac > nbj_consommes_payes) & nbj_rac !=. & nbj_consommes_payes !=. & !(fdd == "O" & reliquat == 0) 
bysort indiv (numero_mois) : replace niar=0 if niar == 1 & niar[_n-1] == 0 & fin_spell == 1 
bysort indiv (numero_mois) : replace niar=0 if niar == 1 & niar[_n+1] == 0 & debut_spell == 1 	
replace niar=. if date < mofd(kdpod) 

capture drop revenu_niar heures_niar
gen revenu_niar = niar*revenu_ar
gen heures_niar = niar*heures_ar

cap drop ar_FNA
gen ar_FNA = ar
replace ar = iar+niar

* Creation AR avant envoi
cap drop ar_avant_envoi
gen ar_avant_envoi_tmp= ar == 1 & (annee==2016 | (annee==2017 & mois==1))
bys kcrna : egen ar_avant_envoi= max(ar_avant_envoi_tmp)
drop ar_avant_envoi_tmp

* Creation IAR avant envoi
cap drop iar_avant_envoi
gen iar_avant_envoi_tmp= (iar == 1 & (annee==2016 | (annee==2017 & mois==1)))
bys kcrna : egen iar_avant_envoi= max(iar_avant_envoi_tmp)
drop iar_avant_envoi_tmp

* Sur les listes au moment du traitement hors AR  
cap drop inliste_jan17
gen inliste_jan17_tmp = (etat_fin_de_mois == "I" | etat_fin_de_mois == "INS" |  etat_fin_de_mois == "NI" | etat_fin_de_mois == "IAR" | etat_fin_de_mois == "NIAR") ///
					   & mois==1 & annee==2017
bys kcrna : egen inliste_jan17= max(inliste_jan17_tmp)
drop inliste_jan17_tmp

cap drop information_subset
gen information_subset = (ar_avant_envoi == 0 & inliste_jan17 == 1) 

* Creation des status
gen groupe_ale=0
replace groupe_ale=1 if groupe_ale_str=="NET" & treated==0
replace groupe_ale=2 if groupe_ale_str=="NET" & treated==1
replace groupe_ale=3 if groupe_ale_str=="BRUT" & treated==0 
replace groupe_ale=4 if groupe_ale_str=="BRUT" & treated==1

gen supercontrole=(groupe_ale_str=="CC")

gen status = .
replace status = 1 if groupe_ale_str == "CC"
replace status = 2 if groupe_ale == 1
replace status = 3 if groupe_ale == 2 & objet == 1
replace status = 4 if groupe_ale == 2 & objet == 2
replace status = 5 if groupe_ale == 2 & objet == 3
replace status = 6 if groupe_ale == 3 
replace status = 7 if groupe_ale == 4 & objet == 1
replace status = 8 if groupe_ale == 4 & objet == 2
replace status = 9 if groupe_ale == 4 & objet == 3

drop objet groupe_ale_str

gen controle = (status == 2 | status == 6) // indic controles 
gen no_supercontrole = 1 - supercontrole

gen all_sample = 1 

capture drop quarter
gen quarter = qofd(mdy(mois-1, 1, annee)) - 227 // trimester indic
replace quarter = 0 if annee == 2017 & mois == 1 
replace quarter = 4 if annee == 2018 & mois == 1 
replace quarter = 8 if annee == 2019 & mois == 1 
replace quarter = 12 if annee == 2020 & mois == 1 

capture drop year
gen year = yofd(mdy(mois-1, 1, annee)) - 2016 // trimester indic
replace year = 0 if annee == 2017 & mois == 1 
replace year = 1 if annee == 2018 & mois == 1 
replace year = 2 if annee == 2019 & mois == 1 
replace year = 3 if annee == 2020 & mois == 1

*compress
*save "${testing_AR_out}exploitation_panel_tmp", replace

**********************
* STEP 3: we merge with indicateurs_emploi (=SIT_IRE+PAF) to add the exits
**********************

*use "${testing_AR_out}exploitation_panel_tmp", clear

merge 1:1 kcrna annee mois using "${testing_AR_intermediate}indicateurs_emploi.dta", ///
				keepusing(date_deb_contrat_PAF duree_contrat_PAF info_contrat_PAF info_contrat_DPAE source)
drop if _merge==2
drop _merge

gen embauche= (source!="")
label var date_deb_contrat_PAF "Date exacte de l'embauche dans PAF"
label var duree_contrat_PAF "Durée du contrat si embauche dans PAF"
label var info_contrat_PAF "Type de contrat si embauche dans PAF"
label var info_contrat_DPAE "Type de contrat si embauche dans DPAE"
label var source "Table avec l'embauche"
label var embauche "=1 si embauche au cours du mois"

bys indiv (date): gen embauche_3mois= embauche==1 | embauche[_n+1]==1 | embauche[_n-1]==1

label var embauche_3mois "=1 si embauche au cours du mois ou le mois avant ou apres"

gen sortietotale_ac_emb = embauche_3mois * sortietotale

bys indiv (date): replace sortietotale_ac_emb=sortietotale if sortietotale_ac_emb[_n-1]==1


**********************
* STEP 4: modifying/adding additional variables
**********************

cap drop trimestre
gen trimestre= 1 if mois==1 | mois==2 | mois==3
replace trimestre= 2 if mois==4 | mois==5 | mois==6
replace trimestre= 3 if mois==7 | mois==8 | mois==9
replace trimestre= 4 if mois==10 | mois==11 | mois==12

cap drop numero_trimestre
gen numero_trimestre=.

forvalues t=1/4 {
replace numero_trimestre=`t' if annee== 2017 & trimestre==`t'
}

forvalues t=1/4  {
replace numero_trimestre=`t'+4 if annee== 2018 & trimestre==`t'
}
forvalues t=1/4 {
replace numero_trimestre=`t'+8 if annee== 2019 & trimestre==`t'
}
forvalues t=1/4 {
replace numero_trimestre=`t'+12 if annee== 2020 & trimestre==`t'
}
cap drop region
egen region=group(kcass)	

cap drop moisodd
gen moisodd=month(date_odd)

cap drop moisregion
egen moisregion=group(region date)	
label var moisregion "Mois en cours interagit avec la region"

cap drop datefinpot
gen datefinpot= kdpod + kpjdxp
format datefinpot %td
label var datefinpot "Date de fin potentielle de l'indemn au premier jour indemnise"

cap drop moisfinpot
gen moisfinpot=mofd(datefinpot)
format moisfinpot %tm
label var moisfinpot "Mois de fin potentielle de l'indemn au premier jour indemnise"

cap drop depassement
gen depassement_tmp= indemnisation>0 & date>moisfinpot
bysort indiv: egen depassement= max(depassement_tmp)
drop depassement_tmp
label var depassement "=1 si individu indemnise apres la date de fin potentielle"

cap drop presentfin
gen presentfin=sortiedef==0 & date==moisfinpot
label var presentfin "= 1 si tjs pas de sortie définitive à la fin duree potentielle"

cap drop dureepot_janv_2017
gen dureepot_janv_2017=datefinpot-mdy(01,31,2017)
label var dureepot_janv_2017 "Durée potentielle d'indemnisation au 31/01/2017"
label var kpjdxp "Durée potentielle d'indemnisation à l'ouverture des droits"

cap drop epuise
cap drop temp
gen temp=reliquat==0 & numero_mois==37 
bysort indiv: egen epuise=max(temp)
drop temp
label var epuise "Individu a consomme toutes ses allocations à la fin de la periode d'étude"

cap drop epuise_bis
cap drop temp
gen temp=reliquat==0 
bysort indiv: egen epuise_bis=max(temp)
drop temp
label var epuise_bis "Individu a consomme toutes ses allocations au moins une fois sur la periode"

capture drop revenu_iar_w revenu_niar_w heures_iar_w heures_niar_w
winsor revenu_niar, gen(revenu_niar_w) p(0.001)  highonly 
winsor revenu_iar, gen(revenu_iar_w) p(0.001)  highonly 
winsor heures_niar, gen(heures_niar_w) p(0.001)  highonly 
winsor heures_iar, gen(heures_iar_w) p(0.001)  highonly 

cap drop heures_ar
gen heures_ar = heures_iar + heures_niar 
cap drop revenu_ar
gen revenu_ar = revenu_iar + revenu_niar 

capture drop revenu_ar_w heures_ar_w
winsor revenu_ar, gen(revenu_ar_w) p(0.001)  highonly 
winsor heures_ar, gen(heures_ar_w) p(0.001)  highonly 

cap drop revenu_total
gen revenu_total = indemnisation + revenu_iar

cap drop revenu_total_w
gen revenu_total_w = indemnisation + revenu_iar_w

cap drop partial_UB
gen partial_UB = indemnisation 
replace partial_UB = 0 if iar == 0 

* cumulated var 
cap drop ar_cum ar_cum_norm
bysort kcrna (numero_mois) : gen ar_cum = sum(ar) 
gen ar_cum_norm = ar_cum 
replace ar_cum_norm = 1 if ar_cum_norm > 1 

cap drop iar_cum iar_cum_norm
bysort kcrna (numero_mois) : gen iar_cum = sum(iar) 
gen iar_cum_norm = iar_cum 
replace iar_cum_norm = 1 if iar_cum_norm > 1 

cap drop niar_cum niar_cum_norm
bysort kcrna (numero_mois) : gen niar_cum = sum(niar) 
gen niar_cum_norm = niar_cum 
replace niar_cum_norm = 1 if niar_cum_norm > 1 

bysort kcrna (numero_mois) : gen revenu_ar_cum = sum(revenu_ar) 
bysort kcrna (numero_mois) : gen heures_ar_cum = sum(heures_ar) 
bysort kcrna (numero_mois) : gen revenu_niar_cum = sum(revenu_niar) 
bysort kcrna (numero_mois) : gen heures_niar_cum = sum(heures_niar) 
bysort kcrna (numero_mois) : gen revenu_iar_cum = sum(revenu_iar) 
bysort kcrna (numero_mois) : gen heures_iar_cum = sum(heures_iar) 
bysort kcrna (numero_mois) : gen indemnisation_cum = sum(indemnisation) 
bysort kcrna (numero_mois) : gen partial_UB_cum = sum(partial_UB) 
bysort kcrna (numero_mois) : gen nbj_consommes_payes_cum = sum(nbj_consommes_payes) 
bysort kcrna (numero_mois) : gen revenu_total_cum = sum(revenu_total) 

bysort kcrna (numero_mois) : gen revenu_ar_cum_w = sum(revenu_ar_w) 
bysort kcrna (numero_mois) : gen heures_ar_cum_w = sum(heures_ar_w) 
bysort kcrna (numero_mois) : gen revenu_niar_cum_w = sum(revenu_niar_w) 
bysort kcrna (numero_mois) : gen heures_niar_cum_w = sum(heures_niar_w) 
bysort kcrna (numero_mois) : gen revenu_iar_cum_w = sum(revenu_iar_w)  
bysort kcrna (numero_mois) : gen heures_iar_cum_w = sum(heures_iar_w) 
bysort kcrna (numero_mois) : gen revenu_total_cum_w = sum(revenu_total_w) 

gen temp = indemnisation if numero_mois >= 1
bysort kcrna (numero_mois) : gen indemnisation_cum_jan17 = sum(temp) 
drop temp

* new vars on part time unemp 
capture drop med_heures_iar_cum_sc top25_heures_iar_cum_sc
bys numero_mois : egen tmp1 = median(heures_iar_cum) if supercontrole==1 & iar_cum_norm ==1
by numero_mois : egen med_heures_iar_cum_sc = max(tmp1)
bys numero_mois : egen tmp2 = pctile(heures_iar_cum) if supercontrole==1 & iar_cum_norm ==1, p(75) 
by numero_mois : egen top25_heures_iar_cum_sc = max(tmp2) 
drop tmp1 tmp2

capture drop iar_cum_norm_top25 iar_cum_norm_sup_med iar_cum_norm_inf_med
gen iar_cum_norm_top25 = (iar_cum_norm == 1 & heures_iar_cum >= top25_heures_iar_cum)
gen iar_cum_norm_sup_med = (iar_cum_norm == 1 & heures_iar_cum >= med_heures_iar_cum)
gen iar_cum_norm_inf_med = (iar_cum_norm == 1 & heures_iar_cum < med_heures_iar_cum)

cap drop iar_cum_norm_1m 
gen iar_cum_norm_1m = (iar_cum == 1)

cap drop iar_cum_norm_2m 
gen iar_cum_norm_2m = (iar_cum == 2)

cap drop iar_cum_norm_inf2m 
gen iar_cum_norm_inf2m = (iar_cum >= 1 & iar_cum <= 2)

cap drop iar_cum_norm_sup2m 
gen iar_cum_norm_sup2m = (iar_cum >= 2)

cap drop iar_cum_norm_sup3m 
gen iar_cum_norm_sup3m = (iar_cum >= 3)

cap drop iar_cum_norm_sup6m 
gen iar_cum_norm_sup6m = (iar_cum >= 6)

* new vars on unemployment 

capture drop sortiedef_ac_emb sortietotale_reliqpos sortietotale_ac_emb2 sortiedef_ac_emb2
* variables about employment status 
gen sortiedef_ac_emb = (sortietotale_ac_emb == 1 & sortiedef==1)
gen sortietotale_reliqpos = (sortietotale==1 & reliquat > 0 & (etat_fin_de_mois == "" | etat_fin_de_mois == "HINS" | etat_fin_de_mois == "NIAR" | niar == 1)) // DE ne percoit pas d'allocation alors qu'il lui reste des droits
gen sortietotale_ac_emb2 = (sortietotale_ac_emb == 1 | sortietotale_reliqpos==1)
gen sortiedef_ac_emb2 = (sortietotale_ac_emb2 == 1 & sortiedef==1)

capture drop unemp
gen unemp = nbj_consommes_payes > 0 | sortietotale_ac_emb2 == 0
cap drop full_unemp
gen full_unemp = unemp*(iar==0) 
cap drop employ
gen employ = sortietotale_ac_emb2

* cumulative var about employment / unemployment 
cap drop employ_cum unemp_cum
bysort kcrna (numero_mois) : gen employ_cum = sum(employ * numero_mois >=1)
bysort kcrna (numero_mois) : gen unemp_cum = sum(unemp * numero_mois >=1)

* longer employment /unemployment spell after trt
capture drop consecutive_employ consecutive_unemp
bysort kcrna (numero_mois) : gen consecutive_employ = sum(unemp==0)
bysort kcrna (numero_mois) : gen consecutive_unemp = sum(unemp==1)

* last quarter before PBD outcomes *********************************************

* out of unemployment (old)
capture drop sortietotale_lq 
capture drop sortietotale_ac_emb_lq
capture drop sortietotale_ac_emb2_lq

bysort kcrna (numero_mois) : egen sortietotale_lq = max((date==moisfinpot-2 & sortietotale == 1 & sortietotale[_n+1] == 1 & sortietotale[_n+2] == 1) | ///
														(date==moisfinpot-1 & sortietotale == 1 & sortietotale[_n+1] == 1) | ///
														(date==moisfinpot & sortietotale == 1))

bysort kcrna (numero_mois) : egen sortietotale_ac_emb_lq = max((date==moisfinpot-2 & sortietotale_ac_emb == 1 & sortietotale_ac_emb[_n+1] == 1 & sortietotale_ac_emb[_n+2] == 1) | ///
															   (date==moisfinpot-1 & sortietotale_ac_emb == 1 & sortietotale_ac_emb[_n+1] == 1) | ///
													 	       (date==moisfinpot & sortietotale_ac_emb == 1))

bysort kcrna (numero_mois) : egen sortietotale_ac_emb2_lq = max((date==moisfinpot-2 & sortietotale_ac_emb2 == 1 & sortietotale_ac_emb2[_n+1] == 1 & sortietotale_ac_emb2[_n+2] == 1) | ///
														        (date==moisfinpot-1 & sortietotale_ac_emb2 == 1 & sortietotale_ac_emb2[_n+1] == 1) | ///
														        (date==moisfinpot & sortietotale_ac_emb2 == 1))

bysort kcrna (numero_mois) : egen sortietotale_ac_emb2_lm = max(date==moisfinpot & sortietotale_ac_emb2 == 1 & sortietotale_ac_emb2[_n+1] == 1 & sortietotale_ac_emb2[_n+2] == 1)
																											
* definitive exit 
capture drop sortiedef_lq sortiedef_ac_emb_lq sortiedef_ac_emb2_lq
bysort kcrna (numero_mois) : egen sortiedef_lq = max(date>=moisfinpot-2 & date<=moisfinpot & sortiedef == 1)
bysort kcrna (numero_mois) : egen sortiedef_ac_emb_lq = max(date>=moisfinpot-2 & date<=moisfinpot & sortiedef_ac_emb == 1)
bysort kcrna (numero_mois) : egen sortiedef_ac_emb2_lq = max(date>=moisfinpot-2 & date<=moisfinpot & sortiedef_ac_emb2 == 1)

* cumulative outcomes over 1st, 2nd and 3rd year after trt *********************

* Total number of months in unemployment (full + partial) 
bysort indiv (numero_mois): egen tmp12 = sum(unemp * (numero_mois <= 12 & numero_mois >=1))
bysort indiv (numero_mois): egen tmp24 = sum(unemp * (numero_mois <= 24 & numero_mois >=1))
bysort indiv (numero_mois): egen tmp36 = sum(unemp * (numero_mois <= 36 & numero_mois >=1))
capture drop nbm_unemp_1st_y nbm_unemp_2nd_y nbm_unemp_3rd_y nbm_unemp_after_trt nbm_unemp_2y_after_trt
gen nbm_unemp_1st_y = tmp12
gen nbm_unemp_2nd_y = tmp24 - tmp12
gen nbm_unemp_3rd_y = tmp36 - tmp24
drop tmp*
gen nbm_unemp_after_trt = nbm_unemp_1st_y + nbm_unemp_2nd_y + nbm_unemp_3rd_y
gen nbm_unemp_2y_after_trt = nbm_unemp_1st_y + nbm_unemp_2nd_y

* Total number of months in full unemployment
bysort indiv (numero_mois): egen nbm_full_unemp_1st_y = sum(full_unemp * (numero_mois <= 12 & numero_mois >=1))
bysort indiv (numero_mois): egen tmp24 = sum(full_unemp * (numero_mois <= 24 & numero_mois >=1))
bysort indiv (numero_mois): egen tmp36 = sum(full_unemp * (numero_mois <= 36 & numero_mois >=1))
capture drop nbm_full_unemp_2nd_y nbm_full_unemp_3rd_y
gen nbm_full_unemp_2nd_y = tmp24 - nbm_full_unemp_1st_y
gen nbm_full_unemp_3rd_y = tmp36 - tmp24
drop tmp*

* Total number of days with unemployment benefits
bysort indiv (numero_mois): egen tmp12 = max(nbj_consommes_payes_cum * (numero_mois == 12))
bysort indiv (numero_mois): egen tmp24 = max(nbj_consommes_payes_cum * (numero_mois == 24))
bysort indiv (numero_mois): egen tmp36 = max(nbj_consommes_payes_cum * (numero_mois == 36))
cap drop nbj_benef_1st_y
cap drop nbj_benef_2nd_y 
cap drop nbj_benef_3rd_y
gen nbj_benef_1st_y = tmp12
gen nbj_benef_2nd_y = tmp24 - tmp12
gen nbj_benef_3rd_y = tmp36 - tmp24
drop tmp*

* Total number of months with unemployment benefits
bysort indiv (numero_mois): egen tmp12 = sum((sortietotale==0) * (numero_mois <= 12 & numero_mois >=1))
bysort indiv (numero_mois): egen tmp24 = sum((sortietotale==0) * (numero_mois <= 24 & numero_mois >=1))
bysort indiv (numero_mois): egen tmp36 = sum((sortietotale==0) * (numero_mois <= 36 & numero_mois >=1))
capture drop nbm_benef_1st_y nbm_benef_2nd_y nbm_benef_3rd_y nbm_benef_after_trt
gen nbm_benef_1st_y = tmp12
gen nbm_benef_2nd_y = tmp24 - tmp12
gen nbm_benef_3rd_y = tmp36 - tmp24
drop tmp*

* Total amount of unemployment benefits
bysort indiv (numero_mois): egen tmp12 = max(indemnisation_cum * (numero_mois == 12))
bysort indiv (numero_mois): egen tmp24 = max(indemnisation_cum * (numero_mois == 24))
bysort indiv (numero_mois): egen tmp36 = max(indemnisation_cum * (numero_mois == 36))
capture drop indemnisation_1st_y indemnisation_2nd_y indemnisation_3rd_y
gen indemnisation_1st_y = tmp12
gen indemnisation_2nd_y = tmp24 - tmp12
gen indemnisation_3rd_y = tmp36 - tmp24
drop tmp*

* Total number of months in regular employment
bysort indiv (numero_mois): egen nbm_employ_1st_y = sum(sortietotale_ac_emb2 * (numero_mois <= 12 & numero_mois >=1)) 
bysort indiv (numero_mois): egen tmp24 = sum(sortietotale_ac_emb2 * (numero_mois <= 24 & numero_mois >=1))
bysort indiv (numero_mois): egen tmp36 = sum(sortietotale_ac_emb2 * (numero_mois <= 36 & numero_mois >=1))
capture drop nbm_employ_2nd_y nbm_employ_3rd_y
gen nbm_employ_2nd_y = tmp24 - nbm_employ_1st_y
gen nbm_employ_3rd_y = tmp36 - tmp24
drop tmp*

* At least one exit toward employment >= 1month
capture drop employ_sup1m_1st_y employ_sup1m_2nd_y employ_sup1m_3rd_y
bysort indiv (numero_mois): egen employ_sup1m_1st_y = max(sortietotale_ac_emb2 ==1 & year == 1)
bysort indiv (numero_mois): egen employ_sup1m_2nd_y = max(sortietotale_ac_emb2 ==1 & year == 2)
bysort indiv (numero_mois): egen employ_sup1m_3rd_y = max(sortietotale_ac_emb2 ==1 & year == 3)
gen employ_sup1m_after_trt = ((employ_sup1m_1st_y + employ_sup1m_2nd_y + employ_sup1m_3rd_y) >= 1)

* At least one exit toward employment >= 3 months
capture drop employ_sup3m_1st_y employ_sup3m_2nd_y employ_sup3m_3rd_y
bysort indiv (numero_mois): egen employ_sup3m_1st_y = max(sortietotale_ac_emb2 ==1 & sortietotale_ac_emb2[_n+1]==1 & sortietotale_ac_emb2[_n+2]==1 & year == 1)
bysort indiv (numero_mois): egen employ_sup3m_2nd_y = max(sortietotale_ac_emb2 ==1 & sortietotale_ac_emb2[_n+1]==1 & sortietotale_ac_emb2[_n+2]==1 & year == 2)
bysort indiv (numero_mois): egen employ_sup3m_3rd_y = max(sortietotale_ac_emb2 ==1 & sortietotale_ac_emb2[_n+1]==1 & sortietotale_ac_emb2[_n+2]==1 & year == 3)
gen employ_sup3m_after_trt = ((employ_sup3m_1st_y + employ_sup3m_2nd_y + employ_sup3m_3rd_y) >= 1)

* At least one exit toward employment >= 6 months
capture drop employ_sup6m_1st_y employ_sup6m_2nd_y employ_sup6m_3rd_y employ_sup6m_after_trt
bysort indiv (numero_mois): egen employ_sup6m_1st_y = max(sortietotale_ac_emb2 == 1 & sortietotale_ac_emb2[_n+1]==1 & sortietotale_ac_emb2[_n+2]==1 & sortietotale_ac_emb2[_n+3] & sortietotale_ac_emb2[_n+4]==1 & sortietotale_ac_emb2[_n+5]==1 & year == 1)
bysort indiv (numero_mois): egen employ_sup6m_2nd_y = max(sortietotale_ac_emb2 == 1 & sortietotale_ac_emb2[_n+1]==1 & sortietotale_ac_emb2[_n+2]==1 & sortietotale_ac_emb2[_n+3] & sortietotale_ac_emb2[_n+4]==1 & sortietotale_ac_emb2[_n+5]==1 & year == 2)
bysort indiv (numero_mois): egen employ_sup6m_3rd_y = max(sortietotale_ac_emb2 == 1 & sortietotale_ac_emb2[_n+1]==1 & sortietotale_ac_emb2[_n+2]==1 & sortietotale_ac_emb2[_n+3] & sortietotale_ac_emb2[_n+4]==1 & sortietotale_ac_emb2[_n+5]==1 & year == 3)
gen employ_sup6m_after_trt = (employ_sup6m_1st_y + employ_sup6m_2nd_y + employ_sup6m_3rd_y >= 1)

compress

save "${testing_AR_out}exploitation_panel_mai20", replace
erase "${testing_AR_out}exploitation_panel_tmp.dta"
