********************************************************************************
********************************************************************************
* Heterogeneous trt effect

* This code creates the data to be used in the heterogeneous trt effect analysis 

********************************************************************************
********************************************************************************

clear all
set more off

* Personalize the file path below
gl testing_AR /Users/pv/Dropbox/Testing_AR/
*gl testing_AR "/Users/pierrecahuc/Dropbox/Testing/Testing_AReduite/"
*gl testing_AR "/Users/helene/Dropbox/#Work/#Projets/Testing AR/Testing_AR/"

gl testing_AR_in "${testing_AR}Prog/Prog for JHR/Data/Raw data/"	
gl testing_AR_intermediate "${testing_AR}Prog/Prog for JHR/Data/Intermediate tables/"
gl testing_AR_out "${testing_AR}Prog/Prog for JHR/Data/Final table/"

********************************************************************************

use "${testing_AR_in}pop_pour_tirage.dta", clear

* 1.1 Strata at the ALE level
********************************************************************************

* Remove duplicates
duplicates drop kcrna, force 

* Create a table for ALE
bysort kcala: egen mean_tx_chge=mean(tx_chge)
bysort kcala: egen mean_femme=mean(femme)
bysort kcala: egen mean_age=mean(age)
bysort kcala: egen mean_senior=mean(senior)
bysort kcala: egen mean_age_intermediaire=mean(age_intermediaire)
bysort kcala: egen mean_jeune=mean(jeune)
bysort kcala: egen mean_contrat_moins_1mois=mean(contrat_moins_1mois)
bysort kcala: egen mean_contrat_moins_3mois=mean(contrat_moins_3mois)
bysort kcala: egen mean_contrat_moins_6mois=mean(contrat_moins_6mois)
bysort kcala: egen mean_contrat_moins_12mois=mean(contrat_moins_12mois)
bysort kcala: egen mean_primaire=mean(primaire)
bysort kcala: egen mean_secondaire=mean(secondaire)
bysort kcala: egen mean_tertiaire=mean(tertiaire)
bysort kcala: egen mean_naf_a=mean(naf_a)
bysort kcala: egen mean_naf_b=mean(naf_b)
bysort kcala: egen mean_naf_c=mean(naf_c)
bysort kcala: egen mean_naf_d=mean(naf_d)
bysort kcala: egen mean_naf_e=mean(naf_e)
bysort kcala: egen mean_naf_f=mean(naf_f)
bysort kcala: egen mean_naf_g=mean(naf_g)
bysort kcala: egen mean_naf_h=mean(naf_h)
bysort kcala: egen mean_naf_i=mean(naf_i)
bysort kcala: egen mean_naf_j=mean(naf_j)
bysort kcala: egen mean_naf_k=mean(naf_k)
bysort kcala: egen mean_naf_l=mean(naf_l)
bysort kcala: egen mean_naf_m=mean(naf_m)
bysort kcala: egen mean_naf_n=mean(naf_n)
bysort kcala: egen mean_naf_o=mean(naf_o)
bysort kcala: egen mean_naf_p=mean(naf_p)
bysort kcala: egen mean_naf_q=mean(naf_q)
bysort kcala: egen mean_naf_r=mean(naf_r)
bysort kcala: egen mean_naf_s=mean(naf_s)
bysort kcala: egen mean_grand_pole=mean(grand_pole)
bysort kcala: egen mean_moyen_pole=mean(moyen_pole)
bysort kcala: egen mean_petit_pole=mean(petit_pole)
bysort kcala: egen mean_hors_pole=mean(hors_pole)
bysort kcala: egen mean_higher_edu=mean(higher_edu)
bysort kcala: egen mean_upper_2nd_edu=mean(upper_2nd_edu)
bysort kcala: egen mean_lower_2nd_edu=mean(lower_2nd_edu)
bysort kcala: egen mean_second_edu=mean(second_edu)
bysort kcala: egen mean_single=mean(single)
bysort kcala: egen mean_married=mean(married)
bysort kcala: egen mean_divorced=mean(divorced)
bysort kcala: egen mean_foreigner=mean(foreigner)
bysort kcala: egen mean_parent=mean(parent)
bysort kcala: egen mean_idf=mean(idf)
bysort kcala: egen mean_actifs=mean(actifs)
bysort kcala: egen mean_tx_chge_jeunes=mean(tx_chge_jeunes)
bysort kcala: egen mean_kpjdxp=mean(kpjdxp)
bysort kcala: egen mean_anciennete=mean(anciennete)
bysort kcala: egen mean_kqcsjp=mean(kqcsjp)

* We have constant variables by kcala
duplicates drop kcala, force

* Exclude overseas territories (DOM)
drop if substr(kcala,1,2)=="97" | substr(kcala,1,2)=="99"

*count
*861

keep kcala nombre_de nombre_de_rct nombre_de_rct proportion_de_ar proportion_de_renf proportion_de_ld proportion_de_sortants mean*

* There is substantial heterogeneity among ALEs in terms of DE characteristics
*sum mean*
*drop if nombre_de_rct<25

* Remove missing values for the constraints we will use (2 observations)
drop if proportion_de_ar==.
drop if mean_contrat_moins_3mois==.
drop if mean_second_edu==.
drop if mean_tx_chge==.
*3 obs deleted

* Dichotomize continuous variables into categorical variables: created 3 equally sized groups (subject to review?)
capture drop strata_ar
xtile strata_ar= proportion_de_ar , nq(2)
capture drop strata_nbre_de
xtile strata_nbre_de_rct= nombre_de_rct , nq(2)
capture drop strata_tx_chge
xtile strata_tx_chge= mean_tx_chge, nq(2)
capture drop strata_contrat_moins_12mois
xtile strata_contrat_moins_12mois= mean_contrat_moins_12mois, nq(2)
capture drop strata_2nd_edu
xtile strata_2nd_edu= mean_second_edu, nq(2)

* Stratification
capture drop strata
gen strata = strata_nbre_de_rct + strata_ar*10 + strata_tx_chge*100 +strata_2nd_edu*1000 + 10000*strata_contrat_moins_12mois 
tab strata

keep kcala strata
rename strata strata_ALE

save "${testing_AR_intermediate}pop_pour_randomization_tmp.dta", replace

* 1.2 Strata at the DE level
********************************************************************************

clear all
set more off

use "${testing_AR_in}pop_pour_tirage.dta", clear
duplicates drop kcrna, force 

* Matching with ALE sampling
sort kcala 
merge m:1 kcala using "${testing_AR_intermediate}pop_pour_randomization_tmp.dta"

* Removing ALEs not selected
drop if _merge==1
drop _merge
count

* Dichotomize continuous variables into categorical variables
capture drop strata_kpjdxp
xtile strata_kpjdxp= kpjdxp , nq(2)
capture drop strata_anciennete
xtile strata_anciennete= anciennete , nq(2)
capture drop strata_kqcsjp
xtile strata_kqcsjp= kqcsjp , nq(2)
capture drop strata_age
xtile strata_age= age , nq(2)

* Stratification
capture drop strata_DE 
capture drop  strata1 
capture drop  strata2
gen strata1 = strata_kpjdxp + strata_anciennete*10 + strata_kqcsjp*100 + femme*1000 + 10000 
gen strata2= strata_age + second_edu*10 + contrat_moins_12mois*100 + 1000
gen strata_DE =string(strata1)+string(strata2)
tab strata_DE

keep kcrna strata_ALE strata_DE

sort kcrna 

save "${testing_AR_out}pop_pour_randomization.dta", replace
erase "${testing_AR_intermediate}pop_pour_randomization_tmp.dta"
