********************************************************************************
********************************************************************************
***         Create final database 
********************************************************************************
********************************************************************************

clear all
set more off

*To be personalized
*gl testing_AR /Users/pv/Dropbox/Testing_AR/
*gl testing_AR "/Users/pierrecahuc/Dropbox/Testing/Testing_AReduite/"
gl testing_AR "/Users/helene/Dropbox/#Work/#Projets/Testing AR/Testing_AR/"

gl testing_AR_out "${testing_AR}Prog/Prog for JHR/Data/Final table/"
gl testing_AR_in "${testing_AR}Prog/Prog for JHR/Data/Raw data/"



********************************************************************************
* STEP 1: we calculate the hours of work before registration
********************************************************************************

*  Merge between PAF and our table EXPLOITATION to get the last contract before the spell

use "${testing_AR_out}exploitation_panel_mai20", clear // base utilisée
keep individu kdfpe
sort individu kdfpe
rename kdfpe kdfpe_dernier
by individu: keep if _n==1
save "${testing_AR_out}kdfpe_temp", replace


use "${testing_AR_in}hmai20_paf.dta", clear
keep individu kddpe kdfpe kpaffq kcaff
merge m:1 individu using "${testing_AR_out}kdfpe_temp", nogenerate keep(matched)
erase "${testing_AR_out}kdfpe_temp.dta"
format %14.0g individu
sort individu kdfpe
gen odd = (kdfpe == kdfpe_dernier)

* We keep the contract within 1 year before the spell

keep if kdfpe <= kdfpe_dernier & kdfpe >= kdfpe_dernier-365

*number of hours
replace kpaffq=kpaffq*5 if kcaff =="J" 
gen max_heures =1825
egen kpaffq_heures = rowmin(kpaffq max_heures) if kcaff =="J" 

replace kpaffq_heures = kpaffq if kcaff =="H"
replace kpaffq_heures = kpaffq * 12 if kcaff =="C"
replace kpaffq_heures = kpaffq * 8 if kcaff =="G"
replace kpaffq_heures = kpaffq * 7 if kcaff =="E" | kcaff=="I"


gen heures_mens_avant_odd = kpaffq_heures if odd==1
replace heures_mens_avant_odd = kpaffq_heures if odd==0 & kddpe >= kdfpe_dernier-365
replace heures_mens_avant_odd = kpaffq_heures * (kdfpe - (kdfpe_dernier-365) +1)/365 if odd==0 & kddpe < kdfpe_dernier-365

* starting date of the frst contract

by individu : egen kddpe_min= min(kddpe)
format %td kddpe_min

gen duree_employment_spell = min(kdfpe_dernier - kddpe_min, 365) 

gen count_rows = 1

* hours of work before the spell

collapse (sum) heures_mens_avant_odd duree_employment_spell count_rows, by(individu)

replace duree_employment_spell = duree_employment_spell/count_rows

replace heures_mens_avant_odd = heures_mens_avant_odd/(duree_employment_spell / 30.4)

drop count_rows duree_employment_spell

save "${testing_AR_out}heures_avant_odd", replace


********************************************************************************
* STEP 2: Merge with our table et we calcule the number of hours when they exit
********************************************************************************


use "${testing_AR_out}exploitation_panel_mai20", clear // base utilisée
merge m:1 individu using "${testing_AR_out}heures_avant_odd", nogenerate


bysort kcrna : egen max_sortietotale=max(sortietotale)

gen heures_mensuelles= 0 
replace heures_mensuelles = heures_iar + heures_niar if heures_iar + heures_niar >1
bysort kcrna (numero_mois) : replace heures_mensuelles = heures_iar[_n-1] + heures_niar[_n-1]  if heures_iar[_n-1] + heures_niar[_n-1] >0  & heures_iar + heures_niar ==0 
replace heures_mensuelles = heures_mens_avant_odd if heures_mensuelles ==0 & sortietotale_ac_emb2==1

bysort kcrna (numero_mois) : gen heures_mensuelles_cum= sum(heures_mensuelles)


gen heures_mensuelles_emb2 = 0
replace heures_mensuelles_emb2 = heures_iar + heures_niar if heures_iar + heures_niar >0 & sortietotale_ac_emb2==1
replace heures_mensuelles_emb2 = heures_mens_avant_odd if heures_iar + heures_niar ==0 & sortietotale_ac_emb2==1
replace heures_mensuelles_emb2=. if heures_iar== .  | sortietotale_ac_emb2==.

bysort kcrna (numero_mois) : gen heures_mensuelles_emb2_cum= sum(heures_mensuelles_emb2)


save "${testing_AR_out}exploitation_panel_mai20", replace






